# Lattice ECP5

The {py:mod}`torii.platform.vendor.lattice.ecp5` module provides a base platform to support Lattice ECP5 devices with the [Trellis] and [Diamond] toolchains.

```{eval-rst}

.. autoclass:: torii.platform.vendor.lattice.ecp5.ECP5Platform

```

[Trellis]: https://github.com/YosysHQ/prjtrellis
[Diamond]: https://www.latticesemi.com/latticediamond
